
#ifndef __SPP_H__
#define __SPP_H__

#define SPP_EXIT 0
#define SPP_DATA 1
#define SPP_EOF 2
#define SPP_SIZE 3
#define SPP_GO_TO_URL 3
#define SPP_GO_TO_URL2 4
#define SPP_METADATA 5

#endif
